;; Generated package description from colorful-mode.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "colorful-mode" "1.2.5.0.20260508.152701" "Preview any color in your buffer in real time" '((emacs "28.1") (compat "31") (cl-lib "1.0")) :commit "97a1dc0b3ac6b2706ec3e2f428ea66aea2d91fb6" :authors '(("Elias G. Perez" . "eg642616@gmail.com")) :maintainer '(("Jen-Chieh" . "jcs090218@gmail.com") ("Elias G. Perez" . "eg642616@gmail.com")) :keywords '("faces" "tools" "matching" "convenience") :url "https://github.com/DevelopmentCool2449/colorful-mode")
